Examples – BRDR - Aligning borders

##### Categories

All (8)
Animation (1)
Evaluation (1)
GeojsonLoader (1)
Graph (1)
Lambert72/08 (1)
Loader (2)
NetworkGeometryProcessor (1)
Prediction (2)
Process (1)
Transformation (1)

# Examples

Here you can find several examples how ‘brdr’ can be used:

##### GeojsonLoader

Loader
GeojsonLoader

example how a GeojsonLoader is used to load thematic data

Karel Dieussaert
Jan 14, 2026

##### Lambert72 to Lambert 08

Lambert72/08
Transformation

Simple example to align a data-object after Lambert72/08-transformation

Karel Dieussaert
Jan 14, 2026

##### Get Started

Process

Simple example to get started

Karel Dieussaert
Jan 7, 2026

##### DictLoader

Loader

example how a DictLoader is used to load a Dictionary of thematic data

Karel Dieussaert
Jan 7, 2026

##### Animated GIF

Animation

Example to create a animated GIF showing the principle of brdr

Karel Dieussaert
Jan 7, 2026

##### Prediction

Prediction

Example of a simple prediction by using brdr

Karel Dieussaert
Jan 7, 2026

##### Evaluation

Evaluation

Example of a simple Evaluation by using brdr

Karel Dieussaert
Jan 7, 2026

##### NetworkGeometryProcessor

NetworkGeometryProcessor
Prediction
Graph

Simple example to get started

Karel Dieussaert
Jan 7, 2026
No matching items